##  Restricting To-Do Completion to Assignees
As an admin user, you can choose to enable an optional feature that restricts claiming and completing to-do items to the assigned users only.
When this feature is enabled:
  * Only the assigned user, the to-do creator, or an admin can complete the to-do
  * Other users cannot claim the to-do
  * Assignees, to-do creator, or an admin can reassign the task or add additional assignees as needed


To enable this feature, contact customer support and request activation of the restricted approval mode feature flag for to-dos.
